@@ -28,14 +28,19 @@ Q<<{
 }>> ;
 
 my $parsed = JSON::Tiny::Grammar.parse($JSON) ;
-#$parsed.say ;
-
-dump( $parsed, title => 'Parsed JSON',
-	 does => 
-		(
-		DDTR::MatchDetails, DDTR::PerlString,
-		DDTR::UnicodeGlyphs, DDTR::SuperscribeType, DDTR::SuperscribeAddress,
-		)
-	 ) ;
+#$parsed.gist.say ;
 
 
+my $d = Data::Dump::Tree.new(
+		title => 'Parsed JSON', 
+		#color => False, width => 100, display_info => False, 
+		does => 
+			(
+			DDTR::MatchDetails, DDTR::PerlString,
+			DDTR::UnicodeGlyphs, DDTR::Superscribe,
+			)
+		) ;
+	
+$d.match_string_limit = 40 ;
+$d.dump($parsed) ;
+
